@@ -7,8 +7,6 @@ content:    Tests for SAM.
 """
 # Modules
 from SAM import SAM
-import pandas as pd 
-import numpy as np
 
 
 # Script
@@ -17,6 +15,7 @@ if __name__ == '__main__':
     sam = SAM()
     sam.load_data('example_data/GSE74596_data.csv.gz')
     sam.load_annotations('example_data/GSE74596_ann.csv')
+    sam.preprocess_data()
     sam.run(projection=None)
     sam.run_umap()
     sam.run_tsne()
